api_
forge
0.0.1
Module traits
Module Items
Enums
Traits
In crate api_
forge
Module
api_forge
::
traits
source
·
[
−
]
Enums

Authentication
Method
Enum representing different methods for authentication in an HTTP request.
Data
Transmission
Method
Enum representing different methods for transmitting data in an HTTP request.
Traits

Request
Request
trait.